@@ -1,11 +1,11 @@
 adj.input <-
 function(x,threshold=.5) {
   
-  if(measurement(x) %in% c("nominal","ordinal")){
+  if(memisc::measurement(x) %in% c("nominal","ordinal")){
     
     nlabeled <- sum(is.vlabeled(x),na.rm=TRUE)
     if(nlabeled < threshold*length(x))
-      measurement(x) <- "interval"
+      memisc::measurement(x) <- "interval"
   }
   x
 }
